// Add ESP8266 board from https://arduino.esp8266.com/stable/package_esp8266com_index.json ( File > Preferences, Tools > Board > Board Manager )

#include <TM1637Display.h> // https://github.com/avishorp/TM1637  
#include <NTPClient.h>     // https://github.com/arduino-libraries/NTPClient
#include <ESP8266WiFi.h>
#include <WiFiUdp.h>

// Set up the character arrays for the Wifi ssid and password
const char *ssid     = "********";
const char *password = "********";

// Set the UTC Time offset in seconds
// const long utcOffsetInSeconds = -21600;
const long utcOffsetInSeconds = -18000;

// Define NTP Client to get the time
WiFiUDP ntpUDP;

// Set up the Network Time Protocol Client, update with fresh time every 10 minutes
NTPClient timeClient(ntpUDP, "85.21.78.23", utcOffsetInSeconds, 600000);

// Module connection pins (Digital Pins)
#define CLK 5
#define DIO 4   

// Set up the TM1637 Display
TM1637Display display(CLK, DIO);

void setup() {
  
    // Set the brightness of the display ( 0xff is brightest )
    display.setBrightness(0x1a);

    // Connect to the wifi point
    WiFi.begin(ssid, password);

    // Wait for the wifi to be connected
    while ( WiFi.status() != WL_CONNECTED ) {
        delay(500);
    }

    // Start the time client
    timeClient.begin();
  
}

void loop() {  

    // Update the time client to get the current time
    timeClient.update();

    // Display the hours
    display.showNumberDecEx(timeClient.getHours(), 0b11100000, true, 2, 0);

    // Display the minutes
    display.showNumberDecEx(timeClient.getMinutes(), 0b11100000, true, 2, 2);
  
}
